@@ -22,6 +22,10 @@ class EDFRecordLoader(RecordLoader):
         signal = self.loadSignal(edfFile)
         signal.recordId = recordName
         return signal
+    
+    def getSignalHeaders(self, recordName):
+        edfFile = self.getFilePathSignal(recordName)
+        return self.loadSignalHeaders(edfFile)
 
     def getAnnotationTimeByName(self, name):
         for time, n in zip(self.annotations[0], self.annotations[2]):
@@ -32,9 +36,39 @@ class EDFRecordLoader(RecordLoader):
 
     def loadSignal(self, edfFile, annotations=False):
         recordSignal = RecordSignal()
-
+        headers, f = self.loadSignalHeadersAndHandle(edfFile)
+        
+        if f.annotations_in_file > 0:
+            self.annotations = f.readAnnotations()
+        
+        for header in headers:
+            signalName = header["signalName"]
+            typeStr = header["type"]
+            index = header["index"]
+            
+            signalArray = f.readSignal(index, digital=self.useDigitalSignals)
+            
+            signal = Signal(signalName, signalArray, frequency=header["sample_rate"])
+            signal.typeStr = typeStr
+            signal.setSignalTypeFromTypeStr()
+            signal.isDigital = self.useDigitalSignals
+            signal.digitalMin = header["digital_min"]
+            signal.digitalMax = header["digital_max"]
+            signal.physicalMin = header["physical_min"]
+            signal.physicalMax = header["physical_max"]
+            signal.dimension = header["dimension"]
+            signal.sourceIndex = index
+            signal.prefilter = header["prefilter"]
+            recordSignal.addSignal(signal, signalName)
+            
+        return recordSignal
+    
+    def loadSignalHeaders(self, edfFile, annotations=False):
+        return self.loadSignalHeadersAndHandle(edfFile, annotations)[0]
+    
+    def loadSignalHeadersAndHandle(self, edfFile, annotations=False):
         try:
-            self.log("Read EDF %s" % edfFile)
+            self.logDebug("Read EDF Header %s" % edfFile)
             f = pyedflib.EdfReader(edfFile)
         except Exception as ex:
             raise ParseError("Failed to read EDF File %s: %s" % (edfFile, str(ex)))
@@ -45,34 +79,22 @@ class EDFRecordLoader(RecordLoader):
             raise Exception(
                 "The RecordLoader has no target signals to extract, please specificy 'sourceSignals' with the name of the channels"
             )
-
-        if f.annotations_in_file > 0:
-            self.annotations = f.readAnnotations()
-
+            
         expectedSignals = len(targetSignals)
         addedSignals = []
         ignoredChannels = []
-
+        signalHeaders = []
         for i in range(n):
-            signalArray = f.readSignal(i, digital=self.useDigitalSignals)
             header = f.getSignalHeader(i)
             channelLabel = header["label"]
             signalName = self.chanelNameAliasMap[channelLabel] if channelLabel in self.chanelNameAliasMap else channelLabel
             if signalName in targetSignals:
-                signal = Signal(signalName, signalArray, frequency=header["sample_rate"])
-                signal.typeStr = self.getSignalTypeStrFromDict(signalName)
-                signal.setSignalTypeFromTypeStr()
-                signal.isDigital = self.useDigitalSignals
-                signal.digitalMin = header["digital_min"]
-                signal.digitalMax = header["digital_max"]
-                signal.physicalMin = header["physical_min"]
-                signal.physicalMax = header["physical_max"]
-                signal.dimension = header["dimension"]
-                signal.sourceIndex = i
-                signal.prefilter = header["prefilter"]
-                recordSignal.addSignal(signal, signalName)
-                addedSignals.append(signalName)
+                header["signalName"] = signalName
+                header["type"] = self.getSignalTypeStrFromDict(signalName)
+                header["index"] = i
                 self.channelMap[signalName] = i
+                signalHeaders.append(header)
+                addedSignals.append(signalName)
             else:
                 ignoredChannels.append(signalName)
 
@@ -82,7 +104,19 @@ class EDFRecordLoader(RecordLoader):
             if len(missingchannels) > 0:
                 raise ChannelsNotPresent(missingchannels, edfFile)
 
-        return recordSignal
+        return signalHeaders, f
+
+    def getMetaData(self, recordName):
+        edfFile = self.getFilePathSignal(recordName)
+        f = pyedflib.EdfReader(edfFile)
+        return {
+            "recordId": recordName,
+            "patientName": f.getPatientName(),
+            "patientCode": f.getPatientCode(),
+            "patientAdd": f.getPatientAdditional(),
+            "start": f.getStartdatetime(),
+            "technician": f.getTechnician(),
+        }
 
     # def fillRecordFromEdf(self, record, edfFile):
     #     edf = pyedflib.EdfReader(edfFile)
